@@ -36,7 +36,7 @@ from .exception import RetrofixException
 
 __all__ = ['Field', 'Char', 'Const', 'Account', 'Number', 'Numeric', 'Integer',
     'Date', 'Selection', 'Boolean', 'SIGN_DEFAULT', 'SIGN_12', 'SIGN_N',
-    'SIGN_POSITIVE', 'BOOLEAN_01', 'BOOLEAN_X']
+    'SIGN_POSITIVE', 'BOOLEAN_01', 'BOOLEAN_12', 'BOOLEAN_X']
 
 
 class Field(object):
@@ -68,9 +68,8 @@ class Char(Field):
         self._size = None
 
     def set(self, value):
-        assert len(value) <= self._size, ('Invalid length for field "%s". Max '
-            'length is "%d" but you set "%d".' % (self._name, self._size,
-                len(value)))
+        if len(value) > self._size:
+            value = value[:self._size]
         return super(Char, self).set(value)
 
 
@@ -250,6 +249,11 @@ BOOLEAN_01 = {
     False: '0',
     }
 
+BOOLEAN_12 = {
+    True: '1',
+    False: '2',
+    }
+
 BOOLEAN_X = {
     True: 'X',
     False: ' ',
